
<p align="center">
    <img src="https://i.postimg.cc/s2P93CGN/blue-logo-no-text-svg.png" alt="Rumorz Logo" width="150"/>
</p>

# 🚀 What is Rumorz?

Rumorz tracks 100s of sources across the web and financial markets to extract investments insights and sentiment analytics.
We index a large amount of web data in real-time and use AI Agents to 
save you time reading, staying up to date, and identifying trends and investment
opportunities.


## How does it work?

AI Agents read and analyze web data 24/7 and ingest 100s of pages of text a day into a knowledge graph, allowing
social and semantic analysis at state of the art performance.

<p align="center">
    <img src="https://github.com/rumorz-ai/rumorz/blob/main/docs/assets/architecture.png" alt="Rumorz architecture" width='500'>
</p>


## 🛠️ Install

```bash
pip install rumorz
```

## 🗎 Documentation

[Please visit the official documentation website](https://docs.rumorz.io)

## 🔒 API Access
Sign up to [Rumorz](https://rumorz.io) to get your API key.

# 🚀 Examples
* [Using the SDK Copilot to generate docs.rumorz.io](docs/examples/copilot.py)
* [Real-time summary of the top and bottom cryptocurrencies by 24h sentiment](docs/examples/examples.py)
* [Plot the sentiment scores of Bitcoin over time](docs/examples/bitcoin_sentiment.py)
